@@ -1,12 +1,9 @@
 //! Receives strings by a message channel, queues them and displays them
 //! one by one in popup alert windows.
 
-use crate::config::CONFIG_PATH;
 use crate::VERSION;
 use lazy_static::lazy_static;
 use msgbox::IconType;
-use std::env;
-use std::path::PathBuf;
 use std::sync::mpsc::sync_channel;
 use std::sync::mpsc::Receiver;
 use std::sync::mpsc::RecvTimeoutError;
@@ -35,33 +32,6 @@ lazy_static! {
     );
 }
 
-lazy_static! {
-    /// Some additional debugging information added to the end of error messages.
-    static ref DIALOG_ERR_TAIL: String = {
-        let mut args_str = String::new();
-        for argument in env::args() {
-            args_str.push_str(argument.as_str());
-            args_str.push(' ');
-        };
-
-        format!(
-            "\n\
-            __________\n\
-            Additional technical details:\n\
-            *    Command line parameters:\n\
-            {}\n\
-            *    Configuration file:\n\
-            {}",
-            args_str,
-            &*CONFIG_PATH
-                .as_ref()
-                .unwrap_or(&PathBuf::from("no path found"))
-                .to_str()
-                .unwrap_or_default()
-        )
-    };
-}
-
 lazy_static! {
     /// This mutex does not hold any data. When it is locked, it indicates,
     /// that the `AlertService` is still busy and should not get shut down.
@@ -165,19 +135,6 @@ impl AlertService {
         let _res = BUSY_LOCK.lock();
     }
 
-    #[inline]
-    /// Concatenates some extra debugging info to `msg` and pushes it into
-    /// queue. In case the message queue is full, the method blocks until there
-    /// is more free space. Make sure to initialize before with
-    /// `AlertService::init()`. Returns an `SendError` if nobody listens on
-    /// `rx` of the queue. This can happen, e.g. if `AlertService::init()` has
-    /// not been called before.
-    pub fn push_debug_str(mut msg: String) -> Result<(), SendError<String>> {
-        msg.push_str(&DIALOG_ERR_TAIL);
-
-        Self::push_str(msg)
-    }
-
     #[inline]
     /// Pushes `msg` into queue. In case the message queue is full, the method
     /// blocks until there is more free space. Make sure to initialize before
