@@ -9,10 +9,7 @@ use sanitize_filename_reader_friendly::sanitize;
 use std::borrow::Cow;
 use std::collections::HashMap;
 use std::hash::BuildHasher;
-use std::ops::Deref;
-use std::ops::DerefMut;
 use std::path::Path;
-use std::path::PathBuf;
 use tera::{to_value, try_get_value, Result as TeraResult, Tera, Value};
 
 /// Filter parameter of the `cut_filter()` that limits the maximum length of template variables,
@@ -333,42 +330,6 @@ pub fn remove_filter<S: BuildHasher>(
     Ok(to_value(&map).unwrap_or_default())
 }
 
-/// Tiny wrapper around "Tera context" with some additional information.
-#[derive(Debug, PartialEq)]
-pub struct ContextWrapper {
-    // Collection of substitution variables.
-    ct: tera::Context,
-    // The note's directory path on disk.
-    pub dir_path: PathBuf,
-}
-
-/// A thin wrapper around `tera::Context` storing some additional
-/// information.
-impl ContextWrapper {
-    pub fn new() -> Self {
-        Self {
-            ct: tera::Context::new(),
-            dir_path: PathBuf::new(),
-        }
-    }
-}
-
-/// Auto-dereference for convenient access to `tera::Content`.
-impl Deref for ContextWrapper {
-    type Target = tera::Context;
-
-    fn deref(&self) -> &Self::Target {
-        &self.ct
-    }
-}
-
-/// Auto-dereference for convenient access to `tera::Content`.
-impl DerefMut for ContextWrapper {
-    fn deref_mut(&mut self) -> &mut Self::Target {
-        &mut self.ct
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
