@@ -2,15 +2,45 @@
 
 #[cfg(feature = "message-box")]
 use crate::alert_service::AlertService;
+#[cfg(feature = "message-box")]
 use crate::settings::ARGS;
 #[cfg(feature = "message-box")]
 use crate::settings::RUNS_ON_CONSOLE;
+use crate::CONFIG_PATH;
 use lazy_static::lazy_static;
 use log::LevelFilter;
 use log::{Level, Metadata, Record};
+use std::env;
 use std::path::PathBuf;
 use std::sync::atomic::{AtomicBool, Ordering};
 
+lazy_static! {
+    /// Some additional debugging information added to the end of error messages.
+    pub static ref ERR_MSG_TAIL: String = {
+        let mut args_str = String::new();
+        for argument in env::args() {
+            args_str.push_str(argument.as_str());
+            args_str.push(' ');
+        };
+
+        format!(
+            "\n\
+            __________\n\
+            Additional technical details:\n\
+            *    Command line parameters:\n\
+            {}\n\
+            *    Configuration file:\n\
+            {}",
+            args_str,
+            &*CONFIG_PATH
+                .as_ref()
+                .unwrap_or(&PathBuf::from("no path found"))
+                .to_str()
+                .unwrap_or_default()
+        )
+    };
+}
+
 pub struct AppLogger {
     /// If `true`, all future log events will trigger the opening of a popup
     /// alert window. Otherwise only `Level::Error` will do.
@@ -81,19 +111,13 @@ impl log::Log for AppLogger {
 
     fn log(&self, record: &Record<'_>) {
         if self.enabled(record.metadata()) {
+            let mut msg = format!("{}:\n{}", record.level(), &record.args().to_string());
+            if record.metadata().level() == Level::Error {
+                msg.push_str(&ERR_MSG_TAIL);
+            };
+
             // Log this to `stderr`.
-            eprintln!(
-                "*** {}: {}\n\
-                 *   The command line argument <path> was:\n{}",
-                record.level(),
-                record.args(),
-                ARGS.path
-                    .as_ref()
-                    .unwrap_or(&PathBuf::new())
-                    .as_os_str()
-                    .to_str()
-                    .unwrap_or_default()
-            );
+            eprintln!("*** {}", msg);
 
             // Eventually also log as popup alert window.
             #[cfg(feature = "message-box")]
@@ -103,17 +127,14 @@ impl log::Log for AppLogger {
                         // This lock can never get poisoned, so `unwrap()` is safe here.
                         || APP_LOGGER.popup_always_enabled.load(Ordering::SeqCst))
             {
-                let msg = format!("{}:\n{}", record.level(), &record.args().to_string());
                 // We silently ignore failing pushes. We have printed the
                 // error message on the console already.
-                let _res = if record.metadata().level() == Level::Error {
-                    AlertService::push_debug_str(msg)
-                } else {
-                    AlertService::push_str(msg)
-                };
+                let _ = AlertService::push_str(msg);
             };
         }
     }
 
-    fn flush(&self) {}
+    fn flush(&self) {
+        Self::flush();
+    }
 }
